#coding=utf-8
'''
Created on 2014年9月8日

@author: dell
'''
def fab(max): 
    n, a, b = 0, 0, 1 
    while n < max: 
        print b 
        a, b = b, a + b 
        n = n + 1

def fab2(max): 
    n, a, b = 0, 0, 1 
    L = [] 
    while n < max: 
        L.append(b) 
        a, b = b, a + b 
        n = n + 1 
    return L

class Fab(object): 

    def __init__(self, max): 
        self.max = max 
        self.n, self.a, self.b = 0, 0, 1 

    def __iter__(self): 
        return self 

    def next(self): 
        if self.n < self.max: 
            r = self.b 
            self.a, self.b = self.b, self.a + self.b 
            self.n = self.n + 1 
            return r 
        raise StopIteration()
    
def fab4(max): 
    n, a, b = 0, 0, 1 
    while n < max: 
        yield b 
        # print b 
        a, b = b, a + b 
        n = n + 1 

if __name__ == '__main__':
    #fab(5)
    
    #for n in fab2(5): 
    #    print n
    
    #for n in Fab(5): 
    #    print n
    
    for n in fab4(5): 
        print n 
    pass


from distutils.core import setup
setup(
	name = 'Fibo',
	version = '1.0.0',
	py_modules = ['Fibo'],
	author = 'xingning',
	author_email = 'xingningjing0507@163.com',
	url = 'http://www.baidu.com',
	description = 'Some functions about Fibo',
)
